import React, {PureComponent} from "react";
import {CommentsWrapper, CommentTextarea} from '../style';
import {getFormatTime, getTime} from '../../../lib/public';
import {Pagination, message} from 'antd';
import axios from "axios";
import {isLogin} from '../../../lib/auth';

class Comments extends PureComponent {
    constructor(props) {
        super(props);
        this.state = {
            id: props.id,
            allowComment: props.allowComment,
            commentCnt: props.commentCnt,

            commentsList: [],
            value: '',
            parentId: '',
            preContent: ''
        };

        this.setValue = this.setValue.bind(this);
        this.addComments = this.addComments.bind(this);
        this.reply = this.reply.bind(this);
    }

    render() {
        const {id, commentsList, allowComment, commentCnt} = this.state;

        // 定义递归渲染子评论的函数
        const renderComments = (comments) => {
            return (
                <ul className='comments'>
                    {comments.map((item, index) => (
                        <li className='comment' key={index}>
                            <div className='commentinfo flex-items'>
                                <img src={item.author_avatar} alt=""/>
                                <div className='commeta cell'>
                                    <h2>{item.author_name}</h2>
                                    <h3>{getTime(item.create_time)} | {getFormatTime(item.create_time)}</h3>
                                </div>
                                <span onClick={() => this.reply(item.id, item.author_name)} className='comment-reply-link'>Reply</span>
                            </div>
                            <div className='body'>
                                <p>{item.ref_author_name && <span>@{item.ref_author_name}</span>}{item.content}</p>
                            </div>
                            <hr/>
                            {item.children && renderComments(item.children)}
                        </li>
                    ))}
                </ul>
            );
        };


        return (
            <CommentsWrapper>
                <h3 className='comments-list-title'>Comments | <span className="noticom">{commentCnt} 条评论 </span>
                </h3>
                <ul className='commentwrap'>
                    {renderComments(commentsList)}
                </ul>

                {allowComment === 1 ? <CommentTextarea>
                    <textarea
                        placeholder="你是我一生只会遇见一次的惊喜 ..."
                        name="comment"
                        className="commentbody"
                        id="comment"
                        rows="5" tabIndex="4"
                        value={this.state.value}
                        onChange={this.setValue}
                    />
                    <div className='form-submit'>
                        <input
                            onClick={this.addComments}
                            name="submit"
                            type="submit"
                            id="submit"
                            className="submit"
                            value="BiuBiuBiu~"
                        />
                    </div>
                </CommentTextarea> : <p className='text'>此处评论已关闭</p>}
            </CommentsWrapper>
        )
    }

    componentDidMount() {
        this.getComments(this.props.id, 1);
    }

    reply(parentId, authorName) {
        this.setState({
            value: `@${authorName}：`,
            preContent: `@${authorName}：`,
            parentId: parentId
        });
    }

    // itemRender(current, type, originalElement) {
    //     if (type === 'prev') {
    //         return <span>« Older</span>;
    //     }
    //     if (type === 'next') {
    //         return <span>Newer »</span>;
    //     }
    //     return originalElement;
    // }

    setValue(e) {
        const value = e.target.value;
        this.setState((prevState) => {
            return {
                value: value,
                parentId: value ? prevState.parentId : '',
                preContent: value ? prevState.preContent : '',
            }
        });
    }

    addComments() {
        const {value, id, parentId, preContent} = this.state;

        const data = {content: value, article_id: parseInt(id)};
        if (value === '') {
            message.warning('please type a comment');
            return false
        }
        if (parentId) {
            let content = value.replace(preContent, "");
            if (content === '') {
                message.warning('please type a comment');
                return false
            }
            if (value.indexOf(preContent, 0) !== -1) {
                data["ref_id"] = parentId;
                data["content"] = content;
            }
        }

        if (!isLogin()){
            this.login();
        }else {
            axios({
                method: 'post',
                url: '/client/comment/save',
                data: data
            }).then((res) => {
                if (res.code === 0) {
                    message.success('评论成功');
                    this.setState({
                        value: '',
                        parentId: ''
                    });
                    this.getComments(id, 1);
                } else {
                    message.success('评论失败');
                }
            });
        }
    }

    login() {
        // 获取当前页面的完整 URL 作为 state 参数
        const currentState = window.location.href;

        // 构建请求参数
        const params = {
            state: encodeURIComponent(currentState)
        };

        axios.get('/client/oauth/uri', { params }).then((res) => {
            if (res.code === 0 && res.data) {
                window.location.href = res.data;
            } else {
                console.error('Failed to retrieve OAuth URI', res);
            }
        }).catch((error) => {
            console.error('Error during OAuth URI retrieval', error);
        });
    }

    getComments(id, page) {
        axios.get('/client/comment/list_tree_by_article/'+id)
            .then((res) => {
            if (res.code === 0) {
                this.setState({
                    commentsList: res.data
                })
            }
        });
    }
}

export default Comments;
