import React, {PureComponent} from "react";
import {CategoryArticleWrapper, ArticleTop, MainWrapper} from './style';
import {connect} from 'react-redux';
import axios from "axios";
import CatList from "../../components/List";
import PagInation from '../../components/PagInation';
import {getrand} from "../../lib/public";

class Category extends PureComponent {
    constructor(props) {
        super(props);
        this.state = {
            current: 1,
            timg: '',
            id: props.match.params.id,
            finished: false,
            loading: true,
            CategoryList: []
        };
        this.getList = this.getList.bind(this);
    }

    render() {
        const {category} = this.props;
        const {CategoryList, current, finished, loading, id} = this.state;
        return (
            <CategoryArticleWrapper>
                <div className='pattern-center-blank'/>
                <ArticleTop>
                    <div className='pattern-attachment-img'>
                        <img className='lazyload' src={this.state.timg} alt=""/>
                    </div>
                    <div className='pattern-header '>
                        <h1>{this.setCategory(category)}</h1>
                    </div>
                </ArticleTop>
                <MainWrapper>
                    <header className="page-header">
                        <h1 className="page-title">{`分类 “${this.setCategory(category)}” 下的文章`}</h1>
                    </header>
                    <CatList list={CategoryList}/>
                    <PagInation current={current} id={id} finished={finished} loading={loading} getList={this.getList}/>
                </MainWrapper>
            </CategoryArticleWrapper>
        )
    }

    componentDidMount() {
        this.getList(1, this.state.id, true);
        this.getTimg();
    }

    getList(current, id, override) {
        this.setState({loading: true});
        axios.post('/client/article/page', {
            category_id: parseInt(id),

            current: current,
            size: 10
        }).then((res) => {
            if (res.code === 0) {

                let total = res.data.total;
                const records = res.data.records;
                const Img = this.props.ListImg;
                let arr = [];

                for (let i = 0; i < records.length; i++) {
                    arr.push({
                        id: records[i].id,
                        title: records[i].title,
                        thumbnail: records[i].thumbnail || Img[getrand(0, Img.length - 1)].img,
                        commentCnt: records[i].comment_cnt,
                        summary: records[i].summary,
                        viewCnt: records[i].view_cnt,
                        createTime: records[i].create_time,
                    })
                }

                this.setState((prevState) => {
                    return {
                        CategoryList: override ? arr : [...prevState.CategoryList, ...arr],
                        current: current + 1,
                        loading: false
                    }
                });

                if ((res.data.current * res.data.size) > total) {
                    this.setState({
                        finished: true
                    })
                }
            }
        });
    }

    getTimg() {
        const list = this.props.topImg;
        const num = this.getrand(0, list.length - 1);
        this.setState({timg: list[num].img})
    }

    getrand(m, n) {
        return Math.floor(Math.random() * (n - m + 1)) + m;
    }

    setCategory(category) {
        const id = parseFloat(this.props.match.params.id);
        let Text = '';
        const list = category.toJS();
        list.forEach((item) => {
            if (!Text && item.id === id) {
                Text = item.name;
            }
        });
        return Text;
    }
}

const mapState = (state) => {
    return {
        category: state.getIn(['header', 'category']),
        topImg: state.getIn(['image', 'bannerList']),
        ListImg: state.getIn(['image', 'ListImg']),
    }
};

export default connect(mapState)(Category)
