import React, {PureComponent} from "react";
import {BannerWrapper, Center, Focusinfo} from '../style';
import {scrollAnimation} from '../../../lib/auth';
import axios from "axios";

class Banner extends PureComponent {
    constructor(props) {
        super(props);
        this.state = {
            socialList: []
        };
    }

    render() {
        const {banner, innerHeight} = this.props;
        const {introduction, avatar} = this.props.userInfo.toJS();
        const {socialList} = this.state;
        return (
            <BannerWrapper>
                <div className="waveWrapper waveAnimation">
                    <div className="waveWrapperInner bgTop">
                        <div className="wave waveTop"/>
                    </div>
                    <div className="waveWrapperInner bgMiddle">
                        <div className="wave waveMiddle"/>
                    </div>
                    <div className="waveWrapperInner bgBottom">
                        <div className="wave waveBottom"/>
                    </div>
                </div>
                <div className='headertop-down animated'>
                    <span onClick={headerTopDown}><i className='iconfont icon-chevrondown'/></span>
                </div>
                <Center style={{backgroundImage: banner, height: innerHeight + 'px'}}>
                    <Focusinfo>
                        <div className='header-tou'>
                            <img src={avatar} alt=''/>
                        </div>
                        <h1 className='glitch' data-text="SUNRISE">SUNRISE</h1>
                        <div className='header-info'>
                            <p className='ellipsis'>
                                <i className='iconfont icon-quote-left'/>
                                <span>{introduction || 'You got to put the past behind you before you can move on.'}</span>
                                <i className='iconfont icon-quoteright'/>
                            </p>
                            <div className='top-social_v2'>
                                <li onClick={this.props.getBanner}>
                                    <img className='flipx' src={require('../../../statics/images/next-b.svg')} alt=""/>
                                </li>
                                {
                                    socialList.map((item, index) => {
                                        let {icon, content, show_type} = item;
                                        if (show_type === 1) {
                                            return (
                                                <li className='img' key={index}>
                                                    <img src={icon} alt=""/>
                                                    <div className='img-box'>
                                                        <img src={content} alt=""/>
                                                    </div>
                                                </li>
                                            )
                                        } else if (show_type === 2) {
                                            return (
                                                <li className='text' key={index}>
                                                    <img src={icon} alt=""/>
                                                    <div className='text-box'>
                                                        <p>{content}</p>
                                                    </div>
                                                </li>
                                            )
                                        } else if (show_type === 3) {
                                            return (
                                                <li className='link' key={index}>
                                                    <a href={content} target={'_blank'} rel="noopener noreferrer">
                                                        <img src={icon} alt=""/>
                                                    </a>
                                                </li>
                                            )
                                        } else {
                                            return null
                                        }
                                    })
                                }
                                <li onClick={this.props.getBanner}>
                                    <img src={require('../../../statics/images/next-b.svg')} alt=""/>
                                </li>
                            </div>
                        </div>
                    </Focusinfo>
                </Center>
            </BannerWrapper>
        )
    }

    componentDidMount() {
        axios.get('/client/social/list').then((res) => {
            if (res.code === 0) {
                this.setState({
                    socialList: res.data
                })
            }
        });
    }
}

function headerTopDown() {
    const content = document.getElementById('content').offsetTop;
    scrollAnimation(0, content);
}

export default Banner
